@@ -102,7 +102,8 @@ class RPCConnection:
         }
     __constructors_for_chains = {}
 
-    def __init__(self, url=None, chain_spec=None, auth=None, verify_identity=True):
+    def __init__(self, url=None, chain_spec=None, auth=None, verify_identity=True, timeout=1.0):
+        self.timeout = timeout
         self.chain_spec = chain_spec
         self.location = None
         self.basic = None
@@ -322,18 +323,21 @@ class JSONRPCHTTPConnection(HTTPConnection):
                     )
             ho = build_opener(handler)
             install_opener(ho)
-        
+       
+        r = None
         try: 
             r = urlopen(
                 req,
                 data=data.encode('utf-8'),
                 context=ssl_ctx,
+                timeout=self.timeout,
                 )
         except URLError as e:
             raise RPCException(e)
 
-        result = json.load(r)
-        logg.debug('(HTTP) recv {}'.format(result))
+        resp = r.read()
+        logg.debug('(HTTP) recv {}'.format(resp.decode('utf-8')))
+        result = json.loads(resp)
         if o['id'] != result['id']:
             raise ValueError('RPC id mismatch; sent {} received {}'.format(o['id'], result['id']))
         return jsonrpc_result(result, error_parser)
